%define name pcb
%define version 20091103
%define release %mkrel 1

Summary:        An interactive printed circuit board editor
Name:           %{name}
Version:        %{version}
Release:        %{release}
License:        GPLv2
Group:          Sciences/Engineering
URL:            http://pcb.sourceforge.net
Source0:        http://downloads.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
Source1:        pcb-reference-card.pdf
Patch0:         pcb-0.20091103-tools.patch
Patch1:         pcb-0.20091103-example.patch
Patch2:         0001-fix-warnings.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:  tcl, bison, flex, gawk, ImageMagick, gtk2-devel, gd-devel, fontconfig-devel
BuildRequires:  cups, tetex-latex, libice6-devel, desktop-file-utils, intltool, gettext-devel
BuildRequires:  dbus-devel
Requires:       m4
Requires: 	glibc >= 2.10.1
Requires: 	libstdc++6 >= 4.4.1
Obsoletes: 	%name < %version



%description
PCB is an interactive printed circuit board editor.
PCB includes a rats nest feature, design rule checking, and can provide
industry standard RS-274-X (Gerber), NC drill, and centroid data (X-Y data)
output for use in the board fabrication and assembly process. PCB offers
high end features such as an autorouter and trace optimizer which can
tremendously reduce layout time.


%package doc
Summary:         Documentation for PCB, An interactive printed circuit board editor
Group:           Documentation
Requires:        %{name} = %{version}-%{release}
Requires(post):  info
Requires(preun): info

%description doc
This package contains the documentation of PCB, An interactive printed circuit
board editor.


%prep
%setup -q 

# Removes duplicates
%patch0 -p0 -b .duplicates
%patch2 -p1 -b .upstream

#
# Preparing docs for %%doc
#
# renaming to .pcb extension
mv example/LED  example/LED.pcb
mv example/LED2 example/LED2.pcb
%patch1 -p0 -b .examples
%{__sed} -i \
   's|examplesdir = $(pkgdatadir)/examples|examplesdir = @docdir@/examples|' \
   example/libraries/Makefile.*

%{__sed} -i \
   's|tutdir = $(pkgdatadir)/tutorial|tutdir = @docdir@/tutorial|' \
   tutorial/Makefile.*

%build
export WISH=%{_bindir}/wish
export CFLAGS=`echo %optflags | sed "s/-D_FORTIFY_SOURCE=2 // g" -`


%configure2_5x \
    --enable-dbus \
    --disable-update-mime-database \
    --disable-update-desktop-database \
    --docdir=%{_docdir}/%{name}-%{version}

%{__make} 


%install
%{__rm} -rf %{buildroot}
%makeinstall_std

desktop-file-install --vendor="" \
     --add-category="X-MandrivaLinux-MoreApplications-Sciences-Other" \
     --dir=%{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}.desktop 
#
# Additional Examples
#
set +x
dest=%{buildroot}%{_docdir}/%{name}-%{version}/examples
for d in thermal pad puller ; do
   echo -n -e "... Fixing path of $d  \t"
   mkdir -p $dest/$d
   mv $dest/../$d.* $dest/$d
   install -pm 0644 doc/$d.{pcb,pdf} $dest/$d
   sed -i "s|$d.png|examples/$d/$d.png|" $dest/../%{name}.html
   echo "done"
done
set -x


## --- pcb supports for acpcircuits
# http://www.apcircuits.com/resources/links/pcb_unix.html
unzip tools/apctools.zip
install -p -m 755 apc*.pl  %{buildroot}%{_datadir}/%{name}/tools

# Removes duplicates
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/apctools.zip
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/pcb2ncap.tgz

chmod 755 %{buildroot}%{_datadir}/%{name}/tools/{PCB2HPGL,tgo2pcb.tcl,Merge*}


cp -p AUTHORS COPYING README NEWS ChangeLog README_FILES/CHANGES \
      README_FILES/Whats_new_in_2.0 README_FILES/Tools \
      %{buildroot}%{_docdir}/%{name}-%{version}/

%{__rm} -rf %{buildroot}%{_datadir}/info/dir

%{__rm} -f  %{buildroot}%{_docdir}/%{name}-%{version}/refcard*
cp -p %{SOURCE1} %{buildroot}%{_docdir}/%{name}-%{version}


%find_lang %{name}


%check
%{__make} check


%clean
%{__rm} -rf %{buildroot}


%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
update-desktop-database &> /dev/null || :
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
update-desktop-database &> /dev/null || :
update-mime-database %{_datadir}/mime &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%post doc
/sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir || :

%preun doc
if [ $1 = 0 ] ; then
  /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :
fi


%files doc
%{_infodir}/%{name}*
%doc %{_docdir}/%{name}-%{version}/pcb-reference-card.pdf
%doc %{_docdir}/%{name}-%{version}/pcb.ps
%doc %{_docdir}/%{name}-%{version}/*.html
%doc %{_docdir}/%{name}-%{version}/examples/thermal
%doc %{_docdir}/%{name}-%{version}/examples/pad
%doc %{_docdir}/%{name}-%{version}/examples/puller


%files -f %{name}.lang
%defattr(-, root, root, -)
%exclude %{_docdir}/%{name}-%{version}/pcb-reference-card.pdf
%exclude %{_docdir}/%{name}-%{version}/pcb.ps
%exclude %{_docdir}/%{name}-%{version}/*.html
%exclude %{_docdir}/%{name}-%{version}/examples/thermal
%exclude %{_docdir}/%{name}-%{version}/examples/pad
%exclude %{_docdir}/%{name}-%{version}/examples/puller
%doc %{_docdir}/%{name}-%{version}/
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*
%{_datadir}/icons/hicolor/*/mimetypes/application-x-*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/pcb.xml
%{_datadir}/mimelnk/application/x-*.desktop


%changelog
* Wed Jan 20 2010 slick50 <lxgator@gmail.com> 20091103-1pclos2010
- import
